@@ -1,5 +1,5 @@
 package Exception::DB::NoFieldsAvailable;
-$Exception::DB::NoFieldsAvailable::VERSION = '0.023';
+$Exception::DB::NoFieldsAvailable::VERSION = '0.024';
 use base qw(Exception::DB);
 
 =head1 Name
@@ -13,7 +13,7 @@ Base class for DB queries.
 =cut
 
 package QBit::Application::Model::DB::Query;
-$QBit::Application::Model::DB::Query::VERSION = '0.023';
+$QBit::Application::Model::DB::Query::VERSION = '0.024';
 use qbit;
 
 use base qw(QBit::Application::Model::DB::Class);
@@ -656,6 +656,8 @@ sub get_sql_with_data {
         $sql    .= "(\n$offset";
     }
 
+    $sql .= $self->_comment() . "\n$offset" if $self->{'comment'};
+
     $sql .= 'SELECT';
 
     $sql .= ' DISTINCT' if $self->{'__DISTINCT__'};
@@ -773,6 +775,8 @@ sub get_sql_with_data {
     return ($sql, @sql_data);
 }
 
+sub _comment {"/* $_[0]->{'comment'} */"}
+
 =head2 get_all
 
 B<No arguments.>
